@@ -22,8 +22,11 @@ impl BinPaths {
 
 #[cfg(test)]
 mod tests {
+    use crate::test::reset;
+
     #[test]
     fn test_bin_paths() {
+        reset();
         assert_cli!("i");
         assert_cli_snapshot!("bin-paths", @r###"
         ~/data/installs/tiny/3/bin
