@@ -93,8 +93,11 @@ impl ValueEnum for Shell {
 
 #[cfg(test)]
 mod tests {
+    use crate::test::reset;
+
     #[test]
     fn test_completion() {
+        reset();
         assert_cli!("completion", "zsh");
         assert_cli!("completion", "bash");
         assert_cli!("completion", "fish");
