@@ -2,10 +2,11 @@ use clap::Subcommand;
 
 mod git_pre_commit;
 mod github_action;
+mod task_docs;
 
 /// [experimental] Generate files for various tools/services
 #[derive(Debug, clap::Args)]
-#[clap(visible_alias = "gen")]
+#[clap(visible_alias = "g")]
 pub struct Generate {
     #[clap(subcommand)]
     command: Commands,
@@ -15,6 +16,7 @@ pub struct Generate {
 enum Commands {
     GitPreCommit(git_pre_commit::GitPreCommit),
     GithubAction(github_action::GithubAction),
+    TaskDocs(task_docs::TaskDocs),
 }
 
 impl Commands {
@@ -22,6 +24,7 @@ impl Commands {
         match self {
             Self::GitPreCommit(cmd) => cmd.run(),
             Self::GithubAction(cmd) => cmd.run(),
+            Self::TaskDocs(cmd) => cmd.run(),
         }
     }
 }
