@@ -80,7 +80,6 @@ mod tests {
         pipx_uvx = false
         plugin_autoupdate_last_check_duration = "20m"
         python_default_packages_file = "~/.default-python-packages"
-        python_pyenv_repo = "https://github.com/pyenv/pyenv.git"
         quiet = false
         raw = false
         trusted_config_paths = []
@@ -91,6 +90,12 @@ mod tests {
 
         [node]
 
+        [python]
+        default_packages_file = "~/.default-python-packages"
+        pyenv_repo = "https://github.com/pyenv/pyenv.git"
+        venv_auto_create = false
+        venv_stdlib = false
+
         [ruby]
         default_packages_file = "~/.default-gems"
         ruby_build_repo = "https://github.com/rbenv/ruby-build.git"
